# project-goldberg-common

This is the develop branch of the project-goldberg-common repository. This branch is used for development and testing of the project-goldberg-common library. The master branch is used for releases.

## How to use this package inside other projects in development environment

First you need to clone the project-goldberg-common repository:

Then you need to install the project-goldberg-common package in editable mode:

```bash
poetry add --editable <path-to-project-goldberg-common-repository>
```
